==> owncloud-10.2.0.zip: owncloud/apps/files_external/l10n/en_GB.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fetching request tokens failed. Verify that your app key and secret are correct.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Fetching access tokens failed. Verify that your app key and secret are correct.",
    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
    "Step 1 failed. Exception: %s" : "Step 1 failed. Exception: %s",
    "Step 2 failed. Exception: %s" : "Step 2 failed. Exception: %s",
    "External storage" : "External storage",
    "Dropbox App Configuration" : "Dropbox App Configuration",
    "Google Drive App Configuration" : "Google Drive App Configuration",
    "Personal" : "Personal",
    "System" : "System",
    "Grant access" : "Grant access",
    "Error configuring OAuth1" : "Error configuring OAuth1",
    "Error configuring OAuth2" : "Error configuring OAuth2",
    "Generate keys" : "Generate keys",
    "Error generating key pair" : "Error generating key pair",
    "All users. Type to select user or group." : "All users. Type to select user or group.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibility with Mac NFD encoding (slow)",
    "Admin defined" : "Admin defined",
    "Saved" : "Saved",
    "Empty response from the server" : "Empty response from the server",
    "Couldn't access. Please logout and login to activate this mount point" : "Couldn't access. Please logout and login to activate this mount point",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Couldn't get the information from the ownCloud server: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Couldn't get the list of external mount points: {type}",
    "There was an error with message: " : "There was an error with message: ",
    "External mount error" : "External mount error",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Couldn't get the list of Windows network drive mount points: empty response from the server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Some of the configured external mount points are not connected. Please click on the red row(s) for more information",
    "Please enter the credentials for the {mount} mount" : "Please enter the credentials for the {mount} mount",
    "Username" : "Username",
    "Password" : "Password",
    "Credentials saved" : "Credentials saved",
    "Credentials saving failed" : "Credentials saving failed",
    "Credentials required" : "Credentials required",
    "Save" : "Save",
    "Storage with id \"%i\" not found" : "Storage with id \"%i\" not found",
    "Invalid backend or authentication mechanism class" : "Invalid backend or authentication mechanism class",
    "Invalid mount point" : "Invalid mount point",
    "Objectstore forbidden" : "Objectstore forbidden",
    "Invalid storage backend \"%s\"" : "Invalid storage backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Not permitted to use backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Not permitted to use authentication mechanism \"%s\"",
    "Unsatisfied backend parameters" : "Unsatisfied backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Unsatisfied authentication mechanism parameters",
    "Insufficient data: %s" : "Insufficient data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Storage with id \"%i\" is not user editable",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "API key",
    "RSA public key" : "RSA public key",
    "Public key" : "Public key",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Enable SSL",
    "Enable Path Style" : "Enable Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Remote subfolder",
    "Secure https://" : "Secure https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Location",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Host",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP with secret key login",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS using OC login",
    "Username as share" : "Username as share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Service name",
    "Request timeout (seconds)" : "Request timeout (seconds)",
    "<b>Note:</b> " : "<b>Note:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "No external storage configured" : "No external storage configured",
    "Name" : "Name",
    "Storage type" : "Storage type",
    "Scope" : "Scope",
    "Enable encryption" : "Enable encryption",
    "Enable previews" : "Enable previews",
    "Enable sharing" : "Enable sharing",
    "Check for changes" : "Check for changes",
    "Never" : "Never",
    "Once every direct access" : "Once every direct access",
    "External Storage" : "External Storage",
    "Folder name" : "Folder name",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Available for",
    "Add storage" : "Add storage",
    "Advanced settings" : "Advanced settings",
    "Delete" : "Delete",
    "Allow users to mount external storage" : "Allow users to mount external storage",
    "Allow users to mount the following external storage" : "Allow users to mount the following external storage",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Disabling external storage will unmount all storages for all users, are you sure ?",
    "Disable external storage" : "Disable external storage",
    "No URL provided by backend " : "No URL provided by backend ",
    "Error getting OAuth2 URL for " : "Error getting OAuth2 URL for ",
    "You can add external storages in the storage settings" : "You can add external storages in the storage settings",
    "Enable external storage" : "Enable external storage",
    "External storage has been disabled by the administrator" : "External storage has been disabled by the administrator",
    "Please make sure that the app that provides this backend is installed and enabled" : "Please make sure that the app that provides this backend is installed and enabled",
    "Allow sharing on user-mounted external storages" : "Allow sharing on user-mounted external storages"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.1.zip: owncloud/apps/files_external/l10n/en_GB.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Step 1 failed. Exception: %s",
    "Step 2 failed. Exception: %s" : "Step 2 failed. Exception: %s",
    "External storage" : "External storage",
    "Google Drive App Configuration" : "Google Drive App Configuration",
    "Error verifying OAuth2 Code for " : "Error verifying OAuth2 Code for ",
    "Personal" : "Personal",
    "System" : "System",
    "Grant access" : "Grant access",
    "Error configuring OAuth1" : "Error configuring OAuth1",
    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
    "Generate keys" : "Generate keys",
    "Error generating key pair" : "Error generating key pair",
    "All users. Type to select user or group." : "All users. Type to select user or group.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibility with Mac NFD encoding (slow)",
    "Unknown auth backend \"{b}\"" : "Unknown auth backend \"{b}\"",
    "Please make sure that the app that provides this backend is installed and enabled" : "Please make sure that the app that provides this backend is installed and enabled",
    "Admin defined" : "Admin defined",
    "Saved" : "Saved",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Disabling external storage will unmount all storages for all users, are you sure ?",
    "Disable external storage" : "Disable external storage",
    "No URL provided by backend " : "No URL provided by backend ",
    "Error getting OAuth2 URL for " : "Error getting OAuth2 URL for ",
    "Empty response from the server" : "Empty response from the server",
    "Couldn't access. Please logout and login to activate this mount point" : "Couldn't access. Please logout and login to activate this mount point",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Couldn't get the information from the ownCloud server: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Couldn't get the list of external mount points: {type}",
    "There was an error with message: " : "There was an error with message: ",
    "External mount error" : "External mount error",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Couldn't get the list of Windows network drive mount points: empty response from the server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Some of the configured external mount points are not connected. Please click on the red row(s) for more information",
    "Please enter the credentials for the {mount} mount" : "Please enter the credentials for the {mount} mount",
    "Username" : "Username",
    "Password" : "Password",
    "Credentials saved" : "Credentials saved",
    "Credentials saving failed" : "Credentials saving failed",
    "Credentials required" : "Credentials required",
    "Save" : "Save",
    "Storage with id \"%i\" not found" : "Storage with id \"%i\" not found",
    "Invalid backend or authentication mechanism class" : "Invalid backend or authentication mechanism class",
    "Invalid mount point" : "Invalid mount point",
    "Objectstore forbidden" : "Objectstore forbidden",
    "Invalid storage backend \"%s\"" : "Invalid storage backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Not permitted to use backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Not permitted to use authentication mechanism \"%s\"",
    "Unsatisfied backend parameters" : "Unsatisfied backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Unsatisfied authentication mechanism parameters",
    "Insufficient data: %s" : "Insufficient data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Storage with id \"%i\" is not user editable",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "API key",
    "RSA public key" : "RSA public key",
    "Public key" : "Public key",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Remote subfolder",
    "Secure https://" : "Secure https://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Location",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Host",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP with secret key login",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS using OC login",
    "Username as share" : "Username as share",
    "<b>Note:</b> " : "<b>Note:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "No external storage configured" : "No external storage configured",
    "You can add external storages in the storage settings" : "You can add external storages in the storage settings",
    "Name" : "Name",
    "Storage type" : "Storage type",
    "Scope" : "Scope",
    "Enable encryption" : "Enable encryption",
    "Enable previews" : "Enable previews",
    "Enable sharing" : "Enable sharing",
    "Check for changes" : "Check for changes",
    "Never" : "Never",
    "Once every direct access" : "Once every direct access",
    "External Storage" : "External Storage",
    "Enable external storage" : "Enable external storage",
    "External storage has been disabled by the administrator" : "External storage has been disabled by the administrator",
    "Folder name" : "Folder name",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Available for",
    "Add storage" : "Add storage",
    "Advanced settings" : "Advanced settings",
    "Delete" : "Delete",
    "Allow users to mount external storage" : "Allow users to mount external storage",
    "Allow users to mount the following external storage" : "Allow users to mount the following external storage",
    "Allow sharing on user-mounted external storages" : "Allow sharing on user-mounted external storages"
},
"nplurals=2; plural=(n != 1);");
